Struct solana_program::entrypoint::BumpAllocator [−][src]
The bump allocator used as the default rust heap when running programs.
Fields
start: usizelen: usizeTrait Implementations
impl GlobalAlloc for BumpAllocator[src]
impl GlobalAlloc for BumpAllocator[src]unsafe fn alloc(&self, layout: Layout) -> *mut u8[src]
unsafe fn alloc(&self, layout: Layout) -> *mut u8[src]Allocate memory as described by the given layout. Read more
unsafe fn dealloc(&self, _: *mut u8, _: Layout)[src]
unsafe fn dealloc(&self, _: *mut u8, _: Layout)[src]Deallocate the block of memory at the given ptr pointer with the given layout. Read more