Module fees

Module fees 

Current cluster fees.

The fees sysvar provides access to the Fees type, which contains the current FeeCalculator.

Fees implements crate::Sysvar::get and can be loaded efficiently without passing the sysvar account ID to the program.

This sysvar is deprecated and will not be available in the future. Transaction fees should be determined with the getFeeForMessage RPC method. For additional context see the Comprehensive Compute Fees proposal.

See also the Solana documentation on the fees sysvar.

Structs

FeesDeprecated
Transaction fees.

Constants

IDNon-BPF
The const program ID.
SIZE
Serialized size of Fees sysvar account.

Functions

check_id
Returns true if given address is the ID.
id
Returns the ID.