#[repr(C)]pub struct Entry {
pub blockhash: Hash,
pub fee_calculator: FeeCalculator,
}๐Deprecated since 1.9.0:
Please do not use, will no longer be available in the future
Fields
blockhash: Hash๐Deprecated since 1.9.0:
Please do not use, will no longer be available in the future
fee_calculator: FeeCalculator๐Deprecated since 1.9.0:
Please do not use, will no longer be available in the future
Implementations