SysvarId

Trait SysvarId 

pub trait SysvarId {
    // Required methods
    fn id() -> Address;
    fn check_id(address: &Address) -> bool;
}
A type that holds sysvar data and has an associated sysvar Address.

Required Methods

fn id() -> Address

The Address of the sysvar.

fn check_id(address: &Address) -> bool

Returns true if the given address is the ID.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors